@@ -275,30 +275,30 @@ class QueenbeeTask(luigi.Task):
             pass
         logger.info(f'Finished running {self.__class__.__name__}...')
 
-    @staticmethod
-    def load_input_param(input_param):
-        """This function tries to import the values from a file as a Task input
-            parameter.
 
-        It first tries to import the content as a dictionary assuming the input file is
-        a JSON file. If the import as JSON fails it will import the content as string and
-        split them by next line. If there are several items it will return a list,
-        otherwise it will return a single item.
-        """
-        content = ''
-        with open(input_param, 'r') as param:
-            try:
-                content = json.load(param)
-            except json.decoder.JSONDecodeError:
-                # not a JSON file
-                pass
-            else:
-                return content
-        with open(input_param, 'r') as param:
-            content = param.read().splitlines()
-            if len(content) == 1:
-                content = content[0]
-        return content
+def load_input_param(input_param):
+    """This function tries to import the values from a file as a Task input
+        parameter.
+
+    It first tries to import the content as a dictionary assuming the input file is
+    a JSON file. If the import as JSON fails it will import the content as string and
+    split them by next line. If there are several items it will return a list,
+    otherwise it will return a single item.
+    """
+    content = ''
+    with open(input_param, 'r') as param:
+        try:
+            content = json.load(param)
+        except json.decoder.JSONDecodeError:
+            # not a JSON file
+            pass
+        else:
+            return content
+    with open(input_param, 'r') as param:
+        content = param.read().splitlines()
+        if len(content) == 1:
+            content = content[0]
+    return content
 
 
 def local_scheduler():
